import { FormSchema } from '@/components/Form';
import { BasicColumn } from '@/components/Table';

/**查询表单*/
export const searchFormSchema = [
  {
    field: 'strategicName',
    label: ' ',
    component: 'InputSearch',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    colProps: { span: 12 },
  },
  {
    field: 'strategicType',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '策略类型',
      options: [
        { label: 'DB-DB源端DDL处理策略', value: 'DB-DB源端DDL处理策略' },
        { label: 'DB-Kafka源端DDL处理策略', value: 'DB-Kafka源端DDL处理策略' },
        { label: '系统异常策略', value: '系统异常策略' },
        { label: '异常数据策略', value: '异常数据策略' },
        { label: '数据积压策略', value: '数据积压策略' },
        { label: '一致性检查策略', value: '一致性检查策略' },
      ],
    },
    colProps: { span: 10 },
  },
];

export const columnsSystem = [
  {
    title: '策略名称',
    dataIndex: 'strategicName',
    width: 150,
    slots: { customRender: 'strategicName' },
  },
  {
    title: '策略类型',
    dataIndex: 'strategicType',
    width: 150,
    slots: { customRender: 'strategicType' },
  },
];

export const systemColumns: BasicColumn[] = [
  {
    title: '事件详情',
    dataIndex: 'eventDetail',
    width: 150,
  },
  {
    title: '事件处理',
    dataIndex: 'eventHandle',
    width: 300,
    slots: { customRender: 'eventHandle' },
  },
];

export const errorColumns: BasicColumn[] = [
  {
    title: '事件详情',
    dataIndex: 'eventDetail',
    width: 150,
  },
  {
    title: '事件处理',
    dataIndex: 'eventHandle',
    slots: { customRender: 'eventHandle' },
    width: 300,
  },
];

export const dbFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    slot: 'strategicType',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'checkSpan',
    show: ({ model }) => {
      return model.strategicType === '一致性检查策略';
    },
    slot: 'checkSpan',
    defaultValue: 5,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'originType',
    label: '源端数据类型',
    component: 'Select',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    componentProps: {
      options: [
        {
          label: '数据积压策略',
          value: '数据积压策略',
        },
        {
          label: '数据异常策略',
          value: '数据异常策略',
        },
        {
          label: 'DB-DB源端DDL处理策略',
          value: 'DB-DB源端DDL处理策略',
        },
        {
          label: '系统异常策略',
          value: '系统异常策略',
        },
        {
          label: '一致性检查策略',
          value: '一致性检查策略',
        },
        {
          label: 'DB-Kafka源端DDL处理策略',
          value: 'DB-Kafka源端DDL处理策略',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deleteTable',
    label: '数据表删除',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '忽略，目标端数据表和任务配置均不做变更',
          value: '2',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deleteField',
    label: '字段删除',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动删除目标端对应字段，任务配置不做变更',
          value: '2',
        },
        {
          label: '忽略，目标端字段和任务配置均不做变更，自动写入空值',
          value: '3',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addField',
    label: '新增字段',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动为目标端新增字段，任务配置不做变更',
          value: '2',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fieldUpdate',
    label: '字段类型或精度变更',
    defaultValue: '3',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动为目标端更改字段类型或精度，任务配置不做变更',
          value: '2',
        },
        {
          label: '忽略，目标端字段类型或精度不变更',
          value: '3',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addTable',
    label: '新增数据表',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动为目标端更改字段类型或精度，任务配置不做变更',
          value: '2',
        },
        {
          label: '忽略，目标端字段类型或精度不变更',
          value: '3',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'clearTable',
    label: '清空表',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动清空目标端对应数据表中数据',
          value: '2',
        },
        {
          label: '忽略，不清空目标端对应表数据',
          value: '3',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fieldRename',
    label: '字段重命名',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动为目标端字段重命名，任务配置不变更',
          value: '2',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'renameTable',
    label: '表重命名',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-DB源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
        {
          label: '自动为目标端表重命名，并自动发布新版本和重启任务',
          value: '2',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deleteTable',
    label: '数据表删除',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deleteField',
    label: '字段删除',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addField',
    label: '新增字段',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'kafafieldUpdate',
    label: '字段类型或精度变更',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addTable',
    label: '新增数据表',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'clearTable',
    label: '清空表',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fieldRename',
    label: '字段重命名',
    defaultValue: '1',
    show: ({ model }) => {
      return model.strategicType === 'DB-Kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];

export const kafkaFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    slot: 'strategicType',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deleteTable',
    label: '数据表删除',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'deleteField',
    label: '字段删除',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addField',
    label: '新增字段',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fieldUpdate',
    label: '字段类型或精度变更',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addTable',
    label: '新增数据表',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'clearTable',
    label: '清空表',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fieldRename',
    label: '字段重命名',
    show: ({ model }) => {
      return model.strategicType === 'DB-kafka源端DDL处理策略';
    },
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '源端暂停',
          value: '1',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];

export const systemFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    slot: 'strategicType',
    colProps: { lg: 24, md: 24 },
  },
];

export const errorFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    slot: 'strategicType',
    colProps: { lg: 24, md: 24 },
  },
];

export const checkFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    slot: 'strategicType',
    colProps: { lg: 24, md: 24 },
  },
];

export const backlogFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    slot: 'strategicType',
    colProps: { lg: 24, md: 24 },
  },
];

export const clearFormSchema: FormSchema[] = [
  {
    field: 'retainTime',
    label: '执行记录保留时间',
    slot: 'retainTime',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'clearTime',
    label: '清理时间配置',
    slot: 'clearTime',
  },
  {
    field: 'errorData',
    label: '保留未处理完成异常数据',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '是',
          value: '1',
        },
        {
          label: '否',
          value: '2',
        },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'retainDate',
    show: false,
  },
  {
    field: 'retainDay',
    show: false,
  },
];

export const addFormSchema: FormSchema[] = [
  {
    field: 'strategicName',
    label: '策略名称',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    required: true,
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    componentProps: {
      rows: 4,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'strategicType',
    label: '策略类型',
    component: 'Select',
    componentProps: {
      placeholder: '策略类型',
      options: [
        { label: 'DB-DB源端DDL处理策略', value: 'DB-DB源端DDL处理策略' },
        { label: 'DB-Kafka源端DDL处理策略', value: 'DB-Kafka源端DDL处理策略' },
        { label: '系统异常策略', value: '系统异常策略' },
        { label: '数据异常策略', value: '数据异常策略' },
        { label: '数据积压策略', value: '数据积压策略' },
        { label: '—致性检查策略', value: '一致性检查策略' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
];
